drivers/wifi: Check device is of type PCI before checking vendor ID

CB:46865 ("mb, soc/intel: Reorganize CNVi device entries in
devicetree") reorganized the devicetree entries to make the
representation of CNVi device consistent with other internal PCI
devices. Since a dummy generic device is added for the CNVi device,
`emit_sar_acpi_structures()` needs to first check if the device is PCI
before checking the vendor ID. This ensures that SAR table generation
is skipped only for PCIe devices with non-Intel vendor IDs and not for
the dummy generic device.

BUG=b:165105210

Change-Id: I3c8d18538b94ed1072cfcc108552f3a1ac320395
Signed-off-by: Furquan Shaikh <furquan@google.com>
Reviewed-on: https://review.coreboot.org/c/coreboot/+/47364
Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Reviewed-by: EricR Lai <ericr_lai@compal.corp-partner.google.com>
Reviewed-by: Duncan Laurie <dlaurie@chromium.org>
Reviewed-by: Dtrain Hsu <dtrain_hsu@compal.corp-partner.google.com>
diff --git a/src/drivers/wifi/generic/acpi.c b/src/drivers/wifi/generic/acpi.c
index 1cc4bd0..cd5af4e 100644
--- a/src/drivers/wifi/generic/acpi.c
+++ b/src/drivers/wifi/generic/acpi.c
@@ -44,8 +44,11 @@
 	struct wifi_sar_limits sar_limits;
 	struct wifi_sar_delta_table *wgds;
 
-	/* CBFS SAR and SAR ACPI tables are currently used only by Intel WiFi devices. */
-	if (dev->vendor != PCI_VENDOR_ID_INTEL)
+	/*
+	 * If device type is PCI, ensure that the device has Intel vendor ID. CBFS SAR and SAR
+	 * ACPI tables are currently used only by Intel WiFi devices.
+	 */
+	if (dev->path.type == DEVICE_PATH_PCI && dev->vendor != PCI_VENDOR_ID_INTEL)
 		return;
 
 	/* Retrieve the sar limits data */